@@ -68,6 +68,7 @@ QVariant NetworkItem::data(int column, int role) const {
   }
 }
 
+// FIXME shouldn't we check the bufferItemCache here?
 BufferItem *NetworkItem::findBufferItem(BufferId bufferId) {
   BufferItem *bufferItem = 0;
 
@@ -107,7 +108,7 @@ BufferItem *NetworkItem::bufferItem(const BufferInfo &bufferInfo) {
 
   newChild(bufferItem);
 
-  // postprocess... this is necessary because Qt doesn't seem to like adding childs which already have childs on their own
+  // postprocess... this is necessary because Qt doesn't seem to like adding children which already have children on their own
   switch(bufferInfo.type()) {
   case BufferInfo::ChannelBuffer:
     {
@@ -231,8 +232,13 @@ void BufferItem::setActivityLevel(BufferInfo::ActivityLevel level) {
 
 void BufferItem::clearActivityLevel() {
   _activity = BufferInfo::NoActivity;
-  _lastSeenMarkerMsgId = _lastSeenMsgId;
   _firstUnreadMsgId = MsgId();
+
+  // FIXME remove with core proto v11
+  if(!(Client::coreFeatures() & Quassel::SynchronizedMarkerLine)) {
+    _markerLineMsgId = _lastSeenMsgId;
+  }
+
   emit dataChanged();
 }
 
@@ -286,6 +292,8 @@ QVariant BufferItem::data(int column, int role) const {
     return (int)activityLevel();
   case NetworkModel::BufferFirstUnreadMsgIdRole:
     return qVariantFromValue(firstUnreadMsgId());
+  case NetworkModel::MarkerLineMsgIdRole:
+    return qVariantFromValue(markerLineMsgId());
   default:
     return PropertyMapItem::data(column, role);
   }
@@ -307,14 +315,23 @@ void BufferItem::setBufferName(const QString &name) {
   emit dataChanged(0);
 }
 
-void BufferItem::setLastSeenMsgId(const MsgId &msgId) {
+void BufferItem::setLastSeenMsgId(MsgId msgId) {
   _lastSeenMsgId = msgId;
-  if(!isCurrentBuffer()) {
-    _lastSeenMarkerMsgId = msgId;
+
+  // FIXME remove with core protocol v11
+  if(!(Client::coreFeatures() & Quassel::SynchronizedMarkerLine)) {
+    if(!isCurrentBuffer())
+      _markerLineMsgId = msgId;
   }
+
   setActivityLevel(BufferInfo::NoActivity);
 }
 
+void BufferItem::setMarkerLineMsgId(MsgId msgId) {
+  _markerLineMsgId = msgId;
+  emit dataChanged();
+}
+
 bool BufferItem::isCurrentBuffer() const {
   return _bufferInfo.bufferId() == Client::bufferModel()->currentIndex().data(NetworkModel::BufferIdRole).value<BufferId>();
 }
@@ -407,7 +424,7 @@ QString QueryBufferItem::toolTip(int column) const {
   toolTip.append(tr("<b>Query with %1</b>").arg(bufferName()));
 
   if(_ircUser) {
-    if(_ircUser->userModes() != "") toolTip[0].append(QString(" (%1)").arg(_ircUser->userModes()));
+    if(_ircUser->userModes() != "") toolTip[0].append(QString(" (+%1)").arg(_ircUser->userModes()));
     if(_ircUser->isAway()) {
       toolTip[0].append(QString(" (away%1)").arg(!_ircUser->awayMessage().isEmpty() ? (QString(" ") + _ircUser->awayMessage()) : QString()));
     }
@@ -979,13 +996,14 @@ MsgId NetworkModel::lastSeenMsgId(BufferId bufferId) const {
   return _bufferItemCache[bufferId]->lastSeenMsgId();
 }
 
-MsgId NetworkModel::lastSeenMarkerMsgId(BufferId bufferId) const {
+MsgId NetworkModel::markerLineMsgId(BufferId bufferId) const {
   if(!_bufferItemCache.contains(bufferId))
     return MsgId();
 
-  return _bufferItemCache[bufferId]->lastSeenMarkerMsgId();
+  return _bufferItemCache[bufferId]->markerLineMsgId();
 }
 
+// FIXME we always seem to use this (expensive) non-const version
 MsgId NetworkModel::lastSeenMsgId(const BufferId &bufferId) {
   BufferItem *bufferItem = findBufferItem(bufferId);
   if(!bufferItem) {
@@ -1006,6 +1024,16 @@ void NetworkModel::setLastSeenMsgId(const BufferId &bufferId, const MsgId &msgId
   bufferItem->setLastSeenMsgId(msgId);
 }
 
+void NetworkModel::setMarkerLineMsgId(const BufferId &bufferId, const MsgId &msgId) {
+  BufferItem *bufferItem = findBufferItem(bufferId);
+  if(!bufferItem) {
+    qDebug() << "NetworkModel::setMarkerLineMsgId(): buffer is unknown:" << bufferId;
+    Client::purgeKnownBufferIds();
+    return;
+  }
+  bufferItem->setMarkerLineMsgId(msgId);
+}
+
 void NetworkModel::updateBufferActivity(Message &msg) {
   int redirectionTarget = 0;
   switch(msg.type()) {
