@@ -20,12 +20,13 @@
 
 #include "backlogmanager.h"
 
+INIT_SYNCABLE_OBJECT(BacklogManager)
 QVariantList BacklogManager::requestBacklog(BufferId bufferId, MsgId first, MsgId last, int limit, int additional) {
-  emit backlogRequested(bufferId, first, last, limit, additional);
+  REQUEST(ARG(bufferId), ARG(first), ARG(last), ARG(limit), ARG(additional))
   return QVariantList();
 }
 
 QVariantList BacklogManager::requestBacklogAll(MsgId first, MsgId last, int limit, int additional) {
-  emit backlogAllRequested(first, last, limit, additional);
+  REQUEST(ARG(first), ARG(last), ARG(limit), ARG(additional))
   return QVariantList();
 }
