@@ -30,6 +30,9 @@
 
 class ColumnHandleItem : public QObject, public QGraphicsItem {
   Q_OBJECT
+#if QT_VERSION >= 0x040600
+  Q_INTERFACES(QGraphicsItem)
+#endif
 
 public:
   ColumnHandleItem(qreal width, QGraphicsItem *parent = 0);
